@@ -26,7 +26,6 @@ import static org.apache.doris.spark.cfg.ConfigurationOptions.DORIS_TABLET_SIZE;
 import static org.apache.doris.spark.cfg.ConfigurationOptions.DORIS_TABLET_SIZE_DEFAULT;
 import static org.apache.doris.spark.cfg.ConfigurationOptions.DORIS_TABLET_SIZE_MIN;
 import static org.apache.doris.spark.cfg.ConfigurationOptions.DORIS_TABLE_IDENTIFIER;
-import static org.apache.doris.spark.cfg.ConfigurationOptions.DORIS_BENODES;
 import static org.apache.doris.spark.util.ErrorMessages.CONNECT_FAILED_MESSAGE;
 import static org.apache.doris.spark.util.ErrorMessages.ILLEGAL_ARGUMENT_MESSAGE;
 import static org.apache.doris.spark.util.ErrorMessages.PARSE_NUMBER_FAILED_MESSAGE;
@@ -236,7 +235,7 @@ public class RestService implements Serializable {
      * @throws IllegalArgumentException fe nodes is illegal
      */
     @VisibleForTesting
-    public static String randomEndpoint(String feNodes, Logger logger) throws IllegalArgumentException {
+    static String randomEndpoint(String feNodes, Logger logger) throws IllegalArgumentException {
         logger.trace("Parse fenodes '{}'.", feNodes);
         if (StringUtils.isEmpty(feNodes)) {
             logger.error(ILLEGAL_ARGUMENT_MESSAGE, "fenodes", feNodes);
@@ -264,17 +263,6 @@ public class RestService implements Serializable {
                 "/";
     }
 
-    @VisibleForTesting
-    static String getUriStr(String feNode,Settings cfg, Logger logger) throws IllegalArgumentException {
-        String[] identifier = parseIdentifier(cfg.getProperty(DORIS_TABLE_IDENTIFIER), logger);
-        return "http://" +
-                feNode + API_PREFIX +
-                "/" + identifier[0] +
-                "/" + identifier[1] +
-                "/";
-    }
-
-
     /**
      * discover Doris table schema from Doris FE.
      * @param cfg configuration of request
@@ -285,20 +273,10 @@ public class RestService implements Serializable {
     public static Schema getSchema(Settings cfg, Logger logger)
             throws DorisException {
         logger.trace("Finding schema.");
-        List<String> feNodeList = allEndpoints(cfg.getProperty(DORIS_FENODES), logger);
-        for (String feNode: feNodeList) {
-            try {
-                HttpGet httpGet = new HttpGet(getUriStr(feNode,cfg, logger) + SCHEMA);
-                String response = send(cfg, httpGet, logger);
-                logger.debug("Find schema response is '{}'.", response);
-                return parseSchema(response, logger);
-            } catch (ConnectedFailedException e) {
-                logger.info("Doris FE node {} is unavailable: {}, Request the next Doris FE node", feNode, e.getMessage());
-            }
-        }
-        String errMsg = "No Doris FE is available, please check configuration";
-        logger.error(errMsg);
-        throw new DorisException(errMsg);
+        HttpGet httpGet = new HttpGet(getUriStr(cfg, logger) + SCHEMA);
+        String response = send(cfg, httpGet, logger);
+        logger.debug("Find schema response is '{}'.", response);
+        return parseSchema(response, logger);
     }
 
     /**
@@ -359,36 +337,25 @@ public class RestService implements Serializable {
         }
         logger.debug("Query SQL Sending to Doris FE is: '{}'.", sql);
 
-        List<String> feNodeList = allEndpoints(cfg.getProperty(DORIS_FENODES), logger);
-        for (String feNode: feNodeList) {
-            try {
-                HttpPost httpPost = new HttpPost(getUriStr(feNode,cfg, logger) + QUERY_PLAN);
-                String entity = "{\"sql\": \""+ sql +"\"}";
-                logger.debug("Post body Sending to Doris FE is: '{}'.", entity);
-                StringEntity stringEntity = new StringEntity(entity, StandardCharsets.UTF_8);
-                stringEntity.setContentEncoding("UTF-8");
-                stringEntity.setContentType("application/json");
-                httpPost.setEntity(stringEntity);
-
-                String resStr = send(cfg, httpPost, logger);
-                logger.debug("Find partition response is '{}'.", resStr);
-                QueryPlan queryPlan = getQueryPlan(resStr, logger);
-                Map<String, List<Long>> be2Tablets = selectBeForTablet(queryPlan, logger);
-                return tabletsMapToPartition(
-                        cfg,
-                        be2Tablets,
-                        queryPlan.getOpaqued_query_plan(),
-                        tableIdentifiers[0],
-                        tableIdentifiers[1],
-                        logger);
-            } catch (ConnectedFailedException e) {
-                logger.info("Doris FE node {} is unavailable: {}, Request the next Doris FE node", feNode, e.getMessage());
-            }
-        }
-        String errMsg = "No Doris FE is available, please check configuration";
-        logger.error(errMsg);
-        throw new DorisException(errMsg);
+        HttpPost httpPost = new HttpPost(getUriStr(cfg, logger) + QUERY_PLAN);
+        String entity = "{\"sql\": \""+ sql +"\"}";
+        logger.debug("Post body Sending to Doris FE is: '{}'.", entity);
+        StringEntity stringEntity = new StringEntity(entity, StandardCharsets.UTF_8);
+        stringEntity.setContentEncoding("UTF-8");
+        stringEntity.setContentType("application/json");
+        httpPost.setEntity(stringEntity);
 
+        String resStr = send(cfg, httpPost, logger);
+        logger.debug("Find partition response is '{}'.", resStr);
+        QueryPlan queryPlan = getQueryPlan(resStr, logger);
+        Map<String, List<Long>> be2Tablets = selectBeForTablet(queryPlan, logger);
+        return tabletsMapToPartition(
+                cfg,
+                be2Tablets,
+                queryPlan.getOpaqued_query_plan(),
+                tableIdentifiers[0],
+                tableIdentifiers[1],
+                logger);
     }
 
     /**
@@ -517,32 +484,22 @@ public class RestService implements Serializable {
      */
     @Deprecated
     @VisibleForTesting
-    public static String randomBackend(SparkSettings sparkSettings , Logger logger) throws DorisException {
-        return getBackend(sparkSettings, logger);
-    }
-
-    @Deprecated
-    @VisibleForTesting
-    public static String beBackend(SparkSettings sparkSettings , Logger logger) throws DorisException {
-        return getBackend(sparkSettings, logger);
-    }
-
-    /**
-     * choice a Doris BE node to request.
-     * @param logger slf4j logger
-     * @return the chosen one Doris BE node
-     * @throws IllegalArgumentException BE nodes is illegal
-     */
-    @VisibleForTesting
-    public static String randomBackendV2(SparkSettings sparkSettings, Logger logger) throws DorisException {
-        return getBackend(sparkSettings, logger);
-    }
-
-    private static String getBackend(SparkSettings sparkSettings, Logger logger) throws DorisException {
-        List<BackendV2.BackendRowV2> backends = getBackendRows(sparkSettings, logger);
+    public static String randomBackend(SparkSettings sparkSettings , Logger logger) throws DorisException, IOException {
+        String feNodes = sparkSettings.getProperty(DORIS_FENODES);
+        String feNode = randomEndpoint(feNodes, logger);
+        String beUrl =   String.format("http://%s" + BACKENDS, feNode);
+        HttpGet httpGet = new HttpGet(beUrl);
+        String response = send(sparkSettings, httpGet, logger);
+        logger.info("Backend Info:{}", response);
+        List<BackendRow> backends = parseBackend(response, logger);
+        logger.trace("Parse beNodes '{}'.", backends);
+        if (backends == null || backends.isEmpty()) {
+            logger.error(ILLEGAL_ARGUMENT_MESSAGE, "beNodes", backends);
+            throw new IllegalArgumentException("beNodes", String.valueOf(backends));
+        }
         Collections.shuffle(backends);
-        BackendV2.BackendRowV2 backend = backends.get(0);
-        return backend.getIp() + ":" + backend.getHttpPort();
+        BackendRow backend = backends.get(0);
+        return backend.getIP() + ":" + backend.getHttpPort();
     }
 
     /**
@@ -583,72 +540,28 @@ public class RestService implements Serializable {
     }
 
     /**
-     * get Doris BE nodes.
+     * choice a Doris BE node to request.
      * @param logger slf4j logger
-     * @return the Doris BE node
-     * @throws IllegalArgumentException BE nodes is illegal
-     */
-    public static List<BackendV2.BackendRowV2> getBeNodes(SparkSettings sparkSettings, Logger logger) throws DorisException {
-        List<String> backends = allBeEndpoints(sparkSettings.getProperty(DORIS_BENODES),logger);
-        List<BackendV2.BackendRowV2> backendRowV2s = new ArrayList<BackendV2.BackendRowV2>();
-        if (backends == null || backends.isEmpty()) {
-            logger.error(ILLEGAL_ARGUMENT_MESSAGE, "benodes", backends);
-            throw new IllegalArgumentException("benodes", String.valueOf(backends));
-        }
-        BackendV2.BackendRowV2 backendRowV2 = new BackendV2.BackendRowV2();
-        for (int i = 0; i < backends.size(); i++) {
-            String ip = backends.get(i).substring(0,backends.get(i).indexOf(":"));
-            try {
-                Integer port = Integer.valueOf(backends.get(i).substring(backends.get(i).indexOf(":")+1,backends.get(i).length()));
-                /**
-                 * By default, the BE port you enter is is_alive=true
-                 */
-                BackendV2.BackendRowV2 backend =  backendRowV2.of(ip,port,true);
-                backendRowV2s.add(backend);
-            } catch (NumberFormatException e) {
-                logger.error("Doris BE is port error, please check configuration");
-                throw new RuntimeException(e);
-            }
-        }
-        return backendRowV2s;
-    }
-
-    /**
-     * get Doris BE node list.
-     * @param logger slf4j logger
-     * @return the Doris BE node list
+     * @return the chosen one Doris BE node
      * @throws IllegalArgumentException BE nodes is illegal
      */
     @VisibleForTesting
-    public static List<BackendV2.BackendRowV2> getBackendRows(SparkSettings sparkSettings,  Logger logger) throws DorisException {
-        /**
-         * If the specified BE does not exist, the FE mode is used
-         */
-        if(notBeNode(sparkSettings,logger)){
-            List<String> feNodeList = allEndpoints(sparkSettings.getProperty(DORIS_FENODES), logger);
-            for (String feNode : feNodeList){
-                try {
-                    String beUrl =   String.format("http://%s" + BACKENDS_V2, feNode);
-                    HttpGet httpGet = new HttpGet(beUrl);
-                    String response = send(sparkSettings, httpGet, logger);
-                    logger.info("Backend Info:{}", response);
-                    List<BackendV2.BackendRowV2> backends = parseBackendV2(response, logger);
-                    logger.trace("Parse benodes '{}'.", backends);
-                    if (backends == null || backends.isEmpty()) {
-                        logger.error(ILLEGAL_ARGUMENT_MESSAGE, "benodes", backends);
-                        throw new IllegalArgumentException("benodes", String.valueOf(backends));
-                    }
-                    return backends;
-                } catch (ConnectedFailedException e) {
-                    logger.info("Doris FE node {} is unavailable: {}, Request the next Doris FE node", feNode, e.getMessage());
-                }
-            }
-            String errMsg = "No Doris FE is available, please check configuration";
-            logger.error(errMsg);
-            throw new DorisException(errMsg);
-        }else {
-            return  getBeNodes(sparkSettings, logger);
+    public static String randomBackendV2(SparkSettings sparkSettings, Logger logger) throws DorisException {
+        String feNodes = sparkSettings.getProperty(DORIS_FENODES);
+        String feNode = randomEndpoint(feNodes, logger);
+        String beUrl =   String.format("http://%s" + BACKENDS_V2, feNode);
+        HttpGet httpGet = new HttpGet(beUrl);
+        String response = send(sparkSettings, httpGet, logger);
+        logger.info("Backend Info:{}", response);
+        List<BackendV2.BackendRowV2> backends = parseBackendV2(response, logger);
+        logger.trace("Parse beNodes '{}'.", backends);
+        if (backends == null || backends.isEmpty()) {
+            logger.error(ILLEGAL_ARGUMENT_MESSAGE, "beNodes", backends);
+            throw new IllegalArgumentException("beNodes", String.valueOf(backends));
         }
+        Collections.shuffle(backends);
+        BackendV2.BackendRowV2 backend = backends.get(0);
+        return backend.getIp() + ":" + backend.getHttpPort();
     }
 
     static List<BackendV2.BackendRowV2> parseBackendV2(String response, Logger logger) throws DorisException {
@@ -692,7 +605,7 @@ public class RestService implements Serializable {
      */
     @VisibleForTesting
     static List<PartitionDefinition> tabletsMapToPartition(Settings cfg, Map<String, List<Long>> be2Tablets,
-                                                           String opaquedQueryPlan, String database, String table, Logger logger)
+            String opaquedQueryPlan, String database, String table, Logger logger)
             throws IllegalArgumentException {
         int tabletsSize = tabletCountLimitForOnePartition(cfg, logger);
         List<PartitionDefinition> partitions = new ArrayList<>();
@@ -715,61 +628,4 @@ public class RestService implements Serializable {
         }
         return partitions;
     }
-
-    /**
-     * choice a Doris FE node to request.
-     *
-     * @param feNodes Doris FE node list, separate be comma
-     * @param logger  slf4j logger
-     * @return the array of Doris FE nodes
-     * @throws IllegalArgumentException fe nodes is illegal
-     */
-    @VisibleForTesting
-    static List<String> allEndpoints(String feNodes, Logger logger) throws IllegalArgumentException {
-        logger.trace("Parse fenodes '{}'.", feNodes);
-        if (StringUtils.isEmpty(feNodes)) {
-            logger.error(ILLEGAL_ARGUMENT_MESSAGE, "fenodes", feNodes);
-            throw new IllegalArgumentException("fenodes", feNodes);
-        }
-        List<String> nodes = Arrays.stream(feNodes.split(",")).map(String::trim).collect(Collectors.toList());
-        Collections.shuffle(nodes);
-        return nodes;
-    }
-
-    /**
-     * choice a Doris BE node to request.
-     *
-     * @param beNodes Doris BE node list, separate be comma
-     * @param logger  slf4j logger
-     * @return the array of Doris FE nodes
-     * @throws IllegalArgumentException fe nodes is illegal
-     */
-    @VisibleForTesting
-    static List<String> allBeEndpoints(String beNodes, Logger logger) throws IllegalArgumentException {
-        logger.trace("Parse benodes '{}'.", beNodes);
-        if (StringUtils.isEmpty(beNodes)) {
-            logger.error(ILLEGAL_ARGUMENT_MESSAGE, "benodes", beNodes);
-            throw new IllegalArgumentException("benodes", beNodes);
-        }
-        List<String> nodes = Arrays.stream(beNodes.split(",")).map(String::trim).collect(Collectors.toList());
-        Collections.shuffle(nodes);
-        return nodes;
-    }
-
-
-    /**
-     * Doris BE node is not
-     * @param logger slf4j logger
-     * @return  Doris BE node Yes or no
-     */
-    public static Boolean notBeNode(SparkSettings sparkSettings, Logger logger){
-        String beNodes = sparkSettings.getProperty(DORIS_BENODES);
-        if(null == beNodes){
-            return true;
-        }else {
-            return false;
-        }
-    }
-
-
-}
\ No newline at end of file
+}
