@@ -17,9 +17,9 @@
 
 package org.apache.doris.spark.sql
 
-import org.apache.doris.sdk.thrift.{TPrimitiveType, TScanColumnDesc}
 import org.apache.doris.spark.exception.DorisException
 import org.apache.doris.spark.rest.models.{Field, Schema}
+import org.apache.doris.thrift.{TPrimitiveType, TScanColumnDesc}
 import org.apache.spark.sql.types._
 import org.hamcrest.core.StringStartsWith.startsWith
 import org.junit.{Assert, Ignore, Test}
@@ -41,7 +41,7 @@ class TestSchemaUtils extends ExpectedExceptionTest {
     fields :+= DataTypes.createStructField("k1", DataTypes.ByteType, true)
     fields :+= DataTypes.createStructField("k5", DataTypes.LongType, true)
     val expected = DataTypes.createStructType(fields.asJava)
-    Assert.assertEquals(expected, SchemaUtils.convertToStruct(schema, "k1,k5", null))
+    Assert.assertEquals(expected, SchemaUtils.convertToStruct("k1,k5", schema))
   }
 
   @Test
@@ -93,24 +93,4 @@ class TestSchemaUtils extends ExpectedExceptionTest {
 
     Assert.assertEquals(expected, SchemaUtils.convertToSchema(Seq(k1, k2)))
   }
-
-  @Test
-  def testIgnoreTypes(): Unit = {
-
-    val schema = new Schema
-    schema.setStatus(200)
-    val col1 = new Field("col1", "TINYINT", "", 0, 0, "")
-    val col2 = new Field("col2", "BITMAP", "", 0, 0, "")
-    val col3 = new Field("col3", "HLL", "", 0, 0, "")
-    schema.put(col1)
-    schema.put(col2)
-    schema.put(col3)
-
-    var fields = List[StructField]()
-    fields :+= DataTypes.createStructField("col1", DataTypes.ByteType, true)
-    val expected = DataTypes.createStructType(fields.asJava)
-    Assert.assertEquals(expected, SchemaUtils.convertToStruct(schema, null, "bitmap,hll"))
-
-  }
-
 }
